Get CRAN location and first release date for an R package
Source:R/get_first_release.R
get_first_release.RdDetermines whether a package is currently on CRAN, only in the CRAN archive, or in neither location, and returns the earliest known release date.
Arguments
- pkg
Character scalar. Package name.
- cran_package_db
A data frame returned by
tools::CRAN_package_db().- archive_df
A data frame with columns
packageandarchive_date, typically created bybuild_archive_df().- date_only
Logical. If TRUE, return only the release date as a scalar.